jQuery(function ($) {
  $(document).ready(function () {
    let containers = document.querySelectorAll(".dsm-filterable-gallery-container");

    containers.forEach((item, index) => {
      const useLightbox = item.dataset.use_lightbox;
      const innerContainer = item.querySelector(
        ".dsm-filterable-gallery-inner-container"
      );

      if ("on" === useLightbox) {
        jQuery(innerContainer).magnificPopup({
          delegate: ".dsm-filterable-gallery-item",
          type: "image",
          tLoading: "Loading image ",
          gallery: {
            enabled: true,
            navigateByImgClick: true,
            preload: [0, 1],
          },
          image: {
            tError: '<a href="%url%">The image </a> could not be loaded.',
            titleSrc: function (item) {
              const lightboxTitle = item.el[0].dataset.lightbox_title;
              const lightboxCaption = item.el[0].dataset.lightbox_caption;
              const lightboxDescription = item.el[0].dataset.lightbox_description;

              let filterableContent = "";
              filterableContent +=
                typeof lightboxTitle === "undefined" || lightboxTitle === ""
                  ? ""
                  : lightboxTitle;
              filterableContent +=
                typeof lightboxCaption === "undefined" || lightboxCaption === ""
                  ? ""
                  : "<small class='dsm-filterable-image-caption'>" +
                  lightboxCaption +
                  "</small>";

              filterableContent +=
                typeof lightboxDescription === "undefined" ||
                  lightboxDescription === ""
                  ? ""
                  : "<small class='dsm-filterableimage-description'>" +
                  lightboxDescription +
                  "</small>";
              return filterableContent;
            },
          },
        });
      }
    });

    /***
     *
     * shuffle gallery
     *
     */

    function chunk(arr, len) {
      var chunks = [],
        i = 0,
        n = arr.length;

      while (i < n) {
        chunks.push(arr.slice(i, (i += len)));
      }

      return chunks;
    }

    containers.forEach((container) => {
      const itemsContainer = container.querySelector(
        ".dsm-filterable-gallery-inner-container"
      );
      const loadMoreButton = container.querySelector(
        ".dsm-gallery-loadmore-container"
      );
      const numberPagination = container.querySelector(
        ".dsm-gallery-number-pagination-container"
      );

      const filters = container.querySelectorAll(
        ".dsm-filterable-gallery-filter-item"
      );
      const perPage = Number(container.dataset.per_page);
      const usePagination = container.dataset.showpagination === "on";
      const paginationType = container.dataset.paginationtype;
      const speed = Number(container.dataset.speed);

      const shuffleInstance = new Shuffle(itemsContainer, {
        itemSelector: ".dsm-filterable-gallery-item",
        delimiter: ",",
        speed: speed,
        buffer: 1,
      });

      // Create an IntersectionObserver instance
      const observer = new IntersectionObserver((entries) => {
        // Check if the element is intersecting with at least 50% visibility
        if (entries[0].intersectionRatio >= 0.5) {
          shuffleInstance.update();
        }

        // Check if the element is fully visible (100% visibility)
        if (entries[0].isIntersecting) {
          shuffleInstance.update();
        }
      });

      // Start observing the element
      observer.observe(itemsContainer);

      function updatePagination() {
        const totalPages = Number(container.dataset.totalpages);
        numberPagination.innerHTML = "";
        const prevButton = document.createElement("span");
        prevButton.classList.add("dsm-gallery-number-pagination");
        prevButton.setAttribute("data-pagination", "prev");
        prevButton.innerHTML = numberPagination.getAttribute('data-pagination-prev-text');
        numberPagination.appendChild(prevButton);

        new Array(totalPages).fill(0).map((_, index) => {
          const normalizedPageIndex = index + 1;
          const button = document.createElement("span");
          button.innerHTML = normalizedPageIndex;
          button.classList.add("dsm-gallery-number-pagination");
          button.setAttribute("data-pagination", normalizedPageIndex);
          numberPagination.appendChild(button);
        });

        const nextBtn = document.createElement("span");
        nextBtn.classList.add("dsm-gallery-number-pagination");
        nextBtn.setAttribute("data-pagination", "next");
        nextBtn.innerHTML = numberPagination.getAttribute('data-pagination-next-text');
        numberPagination.appendChild(nextBtn);

        handleNumberPagination();
      }

      function getActiveFilterName() {
        const activeFilter = Array.from(filters).find((filter) =>
          filter.classList.contains("dsm-active-filter")
        );

        if (
          activeFilter &&
          activeFilter.hasAttribute("data-category") &&
          activeFilter.dataset.category !== "undefined"
        ) {
          return activeFilter.dataset.category;
        }

        return "all";
      }

      function updatePaginationIndexes(group) {
        const items = container.querySelectorAll(".dsm-filterable-gallery-item");
        const relevantItems = Array.from(items).filter((item) => {
          return item.dataset.groups.split(",").includes(group);
        });
        const pageLength = usePagination ? perPage : relevantItems.length;
        const relevantItemsInPages = chunk(relevantItems, pageLength);

        items.forEach((item) => {
          item.setAttribute("data-inpage", "-1");
        });

        relevantItemsInPages.forEach((itemsInPage, currentPageIndex) => {
          const normalizedPageIndex = currentPageIndex + 1;

          itemsInPage.forEach((item) => {
            item.setAttribute("data-inpage", normalizedPageIndex.toString());
          });
        });
        container.setAttribute("data-totalPages", relevantItemsInPages.length);
        const newItems = container.querySelectorAll(".dsm-filterable-gallery-item");

        const nextPageItems = Array.from(newItems).filter((item) => {
          const itemPage = Number(item.dataset.inpage);
          const isRelevant = item.dataset.groups.split(",").includes(group);
          const nextPageIndex = Number(container.dataset.currentpage) + 1;

          const isInCurrentPage = itemPage === nextPageIndex;
          return isInCurrentPage && isRelevant;
        });
        const prevPageItems = Array.from(newItems).filter((item) => {
          const itemPage = Number(item.dataset.inpage);
          const isRelevant = item.dataset.groups.split(",").includes(group);
          const nextPageIndex = Number(container.dataset.currentpage) - 1;

          const isInCurrentPage = itemPage === nextPageIndex;
          return isInCurrentPage && isRelevant;
        });

        const hasNextPage = nextPageItems.length > 0;
        const hasPrevPage = prevPageItems.length > 0;

        container.setAttribute("data-hasnextpage", String(hasNextPage));
        container.setAttribute("data-hasPrevpage", String(hasPrevPage));
      }

      function loadMore() {
        const currentPage = Number(container.dataset.currentpage);
        const nextPage = currentPage + 1;
        const activeFilter = getActiveFilterName();

        container.setAttribute("data-currentpage", nextPage.toString());
        updatePaginationIndexes(activeFilter);
        applyFilter(activeFilter, nextPage);
      }

      function handleNumberPagination() {
        if (!numberPagination) return;
        const paginations = numberPagination.querySelectorAll(
          ".dsm-gallery-number-pagination"
        );
        let hasPrevPage = Number(container.dataset.currentpage) > 1;
        let hasNextPage = container.dataset.hasnextpage === "true";

        paginations.forEach((pagination) => {
          if (
            !isNaN(pagination.dataset.pagination) &&
            !hasNextPage &&
            !hasPrevPage
          ) {
            pagination.style.display = "none";
          }
          if (
            Number(container.dataset.currentpage) ===
            Number(pagination.dataset.pagination)
          ) {
            pagination.classList.add("dsm-active-pagination-item");
          }
          pagination.addEventListener("click", () => {
            hasNextPage = container.dataset.hasnextpage === "true";
            paginations.forEach((pg) =>
              pg.classList.remove("dsm-active-pagination-item")
            );
            const currentPage = Number(container.dataset.currentpage);
            const paginationPage = pagination.dataset.pagination;
            const activeFilter = getActiveFilterName();
            hasPrevPage = currentPage > 1;
            switch (paginationPage) {
              case "next":
                {
                  if (!hasNextPage) return;
                  const nextPage = currentPage + 1;
                  paginations.forEach((pg) => {
                    const pgPage = pg.dataset.pagination;
                    if (nextPage === Number(pgPage)) {
                      pg.classList.add("dsm-active-pagination-item");
                    }
                  });

                  container.setAttribute("data-currentpage", nextPage);
                  applyFilter(activeFilter, nextPage);
                }
                break;
              case "prev":
                {
                  if (!hasPrevPage) return;
                  const prevPage = currentPage - 1;
                  paginations.forEach((pg) => {
                    const pgPage = pg.dataset.pagination;
                    if (prevPage === Number(pgPage)) {
                      pg.classList.add("dsm-active-pagination-item");
                    }
                  });
                  container.setAttribute("data-currentpage", prevPage);
                  applyFilter(activeFilter, prevPage);
                }
                break;
              default: {
                pagination.classList.add("dsm-active-pagination-item");
                container.setAttribute("data-currentpage", paginationPage);
                applyFilter(activeFilter, Number(paginationPage));
              }
            }
          });
        });
      }

      function resetPagination() {
        container.setAttribute("data-currentpage", "1");
      }

      function handleFilterState(group) {
        filters.forEach((filter) => {
          const currentCategory = filter.dataset.category;
          if (group === currentCategory) {
            filter.classList.add("dsm-active-filter");
          } else {
            filter.classList.remove("dsm-active-filter");
          }
        });
      }

      function applyFilter(group, currentPage = container.dataset.currentpage) {
        currentPage = Number(container.dataset.currentpage);

        shuffleInstance.filter((element) => {
          const elementPage = Number(element.dataset.inpage);
          const elementCategories = element.dataset.groups;

          const isInCurrentPage =
            (paginationType === "number"
              ? elementPage === currentPage
              : elementPage <= currentPage) && elementPage !== -1;
          const isInCurrentCategory = elementCategories.split(",").includes(group);

          return isInCurrentCategory && isInCurrentPage;
        });

        handleFilterState(group);
        updatePaginationIndexes(group);
      }

      filters.forEach((filter) => {
        filter.addEventListener("click", () => {
          const currentCategory = filter.dataset.category;
          updatePaginationIndexes(currentCategory);
          resetPagination();
          applyFilter(currentCategory);
          if (numberPagination) {
            updatePagination();
          }
        });
      });

      if (loadMoreButton) {
        loadMoreButton.addEventListener("click", () => loadMore());
      }
      const initiallyActiveCategory = typeof filters[0] !== "undefined" ? filters[0].dataset.category : "all";
      updatePaginationIndexes(initiallyActiveCategory);
      applyFilter(initiallyActiveCategory);
      handleNumberPagination();
    });
  });
});